@@ -29,7 +29,7 @@ class CharacteristicBuffer:
         characteristic: Characteristic,
         *,
         timeout: float = 1,
-        buffer_size: int = 64
+        buffer_size: int = 64,
     ):
 
         """Monitor the given Characteristic. Each time a new value is written to the Characteristic
